@@ -1,14 +1,5 @@
 from datetime import datetime
-try:
-	from orjson import dumps  # type: ignore
-except ModuleNotFoundError:
-	try:
-		from ujson import dumps as jdumps  # type: ignore
-	except ModuleNotFoundError:
-		from json import dumps as jdumps
-
-	def dumps(*args, **kwargs):  # noqa
-		return jdumps(*args, **kwargs).encode()
+from orjson import dumps
 
 
 class Response:
